@@ -6,13 +6,9 @@ pub fn with_temp_dir<F, R>(f: F) -> R
 where
     F: FnOnce(Arc<TempDir>) -> R,
 {
-    println!("bla");
     let temp_dir = Arc::new(tempdir().unwrap());
 
-    println!("bla");
-    println!("{:?}", temp_dir);
     let old_cd = current_dir().unwrap();
-    println!("bla");
     let _ = set_current_dir(temp_dir.path());
 
     let result = f(temp_dir);
